CastPlusPlugin class

Constructors

CastPlusPlugin()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

deviceUpdateStream Stream<List<CastDevice>>
Returns a stream of cast device list updates.
no setter
statusStream Stream<Map<String, dynamic>>
no setter

Static Methods

castToAirPlay(String url) Future<void>
castToDevice({required String url, required String deviceId, required String deviceUniqueId, required String videoTitle}) Future<void>
getAvailableCastDevices() Future<List<CastDevice>>
initialize() Future<void>
showCastPicker() Future<void>
stopCasting() Future<void>